==> datastructures_0.1.0.tar.gz: datastructures/R/methods_pop.R <==
# datastructures: Implementation of core datastructures for R.
#
# Copyright (C) Simon Dirmeier
#
# This file is part of datastructures.
#
# datastructures is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# datastructures is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with datastructures. If not, see <http://www.gnu.org/licenses/>.


#' @title Pop a single element from an object
#'
#' @description Remove and return the first element from an object.
#'
#' @export
#' @docType methods
#' @rdname pop-methods
#'
#' @param obj  the object to pop an element from
#' @return  returns the first element from  \code{obj}
setGeneric(
    "pop",
    function(obj)
    {
        standardGeneric("pop")
    },
    package = "datastructures"
)

#' @rdname pop-methods
setMethod(
    "pop",
    signature = signature(obj = "queue"),
    function(obj)
    {
        if (obj@.data$list$size())
            obj@.data$list$pop()
        else
            NULL
    }
)

#' @rdname pop-methods
setMethod(
    "pop",
    signature = signature(obj = "fibonacci_heap"),
    function(obj)
    {
        if (obj@.data$heap$size())
            obj@.data$heap$pop()
        else
            NULL
    }
)


#' @rdname pop-methods
setMethod(
    "pop",
    signature = signature(obj = "stack"),
    function(obj)
    {
        if (obj@.data$list$size())
            obj@.data$list$pop()
        else
            NULL
    }
)

==> datastructures_0.2.0.tar.gz: datastructures/R/methods_pop.R <==
# datastructures: Implementation of core datastructures for R.
#
# Copyright (C) Simon Dirmeier
#
# This file is part of datastructures.
#
# datastructures is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# datastructures is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with datastructures. If not, see <http://www.gnu.org/licenses/>.


#' @title Pop a single element from an object
#'
#' @description Remove and return the first element from an object.
#'
#' @export
#' @docType methods
#' @rdname pop-methods
#'
#' @param obj  the object to pop an element from

#' @return  returns the first element from \code{obj} as list
#'
setGeneric(
    "pop",
    function(obj)
    {
        standardGeneric("pop")
    },
    package = "datastructures"
)


#' @noRd
.pop.deque <-  function(obj)
{
    if (obj@.deque$size())
        obj@.deque$pop()
    else
        NULL
}


#' @rdname pop-methods
setMethod("pop", "stack", .pop.deque)


#' @rdname pop-methods
setMethod("pop", "queue", .pop.deque)


#' @noRd
.pop.heap <- function(obj)
{
    if (obj@.heap$size())
        obj@.heap$pop()
    else
        NULL
}


#' @rdname pop-methods
setMethod("pop", "fibonacci_heap", .pop.heap)


#' @rdname pop-methods
setMethod("pop", "binomial_heap", .pop.heap)
